@@ -1,8 +1,10 @@
 import time
+import loggerjava
+
 if __name__ == '__main__':
     pass
 
-ver = "v0.0.7.1"
+ver = "v0.0.7.5"
 name = "log"
 absolutepath = False
 showdetailedtime = False
@@ -11,148 +13,102 @@ filetype = ".log"
 file_encoding = "utf-8"
 route = r"log.log"
 debugin = False
+fatalclose = False
 
 
 # noinspection PyTypeChecker
-def debug(txt, pos="main"):
+def log(txt, type="i", pos="main", **overrides):
     """
         :param txt: the detail description of this log
+        :param type: the type of the log,using:debug,info,warn,error,fatal
         :param pos: show where the log's actual called positon in the code
-        :return:
+        :return: log
         """
-    level = 'debug'
-    if absolutepath:
-        f = open(route, mode="at+", encoding=file_encoding)
-    else:
-        f = open(name + filetype, mode="at+", encoding=file_encoding)
-    if showdetailedtime and showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-        print(_output.format(time.asctime(), pos, level, txt))
-    elif not showdetailedtime and showinconsole:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-        print(_output.format(_output.time1(), pos, level, txt))
-    elif showdetailedtime and not showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-    else:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-    if debugin and not showdetailedtime:
-        return _output.format(_output.time1(), pos, level, txt)
-    elif debugin and showdetailedtime:
-        return _output.format(time.asctime(), pos, level, txt)
-    f.close()
-
-
-def info(txt, pos="main"):
-    """
-        :param txt: the detail description of this log
-        :param pos: show where the log's actual called positon in the code
-        :return:
-        """
-    level = 'INFO'
+    for configname, configdata in overrides.items():
+        pass
+    level = _formats.typeformat(type)
     if absolutepath:
         f = open(route, mode="at+", encoding=file_encoding)
     else:
         f = open(name + filetype, mode="at+", encoding=file_encoding)
     if showdetailedtime and showinconsole:
         # noinspection PyTypeChecker
-        f.write(_output.format(time.asctime(), pos, level, txt))
-        print(_output.format(time.asctime(), pos, level, txt))
+        f.write(_formats.format(time.asctime(), pos, level, txt))
+        print(_formats.format(time.asctime(), pos, level, txt))
     elif not showdetailedtime and showinconsole:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-        print(_output.format(_output.time1(), pos, level, txt))
+        f.write(_formats.format(_formats.time1(), pos, level, txt))
+        print(_formats.format(_formats.time1(), pos, level, txt))
     elif showdetailedtime and not showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
+        f.write(_formats.format(time.asctime(), pos, level, txt))
     else:
-        f.write(_output.format(_output.time1(), pos, level, txt))
+        f.write(_formats.format(_formats.time1(), pos, level, txt))
     if debugin and not showdetailedtime:
-        return _output.format(_output.time1(), pos, level, txt)
+        return _formats.format(_formats.time1(), pos, level, txt)
     elif debugin and showdetailedtime:
-        return _output.format(time.asctime(), pos, level, txt)
+        return _formats.format(time.asctime(), pos, level, txt)
     f.close()
 
 
+def debug(txt, pos="main"):
+    """
+        :param txt: the detail description of this log
+        :param pos: show where the log's actual called positon in the code
+        :return: debug log
+        """
+    if debugin:
+        return log(txt, type='debug', pos=pos)
+    else:
+        log(txt, type='debug', pos=pos)
+
+
+def info(txt, pos="main"):
+    """
+        :param txt: the detail description of this log
+        :param pos: show where the log's actual called positon in the code
+        :return: info log
+        """
+    if debugin:
+        return log(txt, type='INFO', pos=pos)
+    else:
+        return log(txt, type='INFO', pos=pos)
+
+
 def warn(txt, pos="main"):
     """
         :param txt: the detail description of this log
         :param pos: show where the log's actual called positon in the code
-        :return:
+        :return: warning log
         """
-    level = 'WARN'
-    if absolutepath:
-        f = open(route, mode="at+", encoding=file_encoding)
+    if debugin:
+        return log(txt, type='WARN', pos=pos)
     else:
-        f = open(name + filetype, mode="at+", encoding=file_encoding)
-    if showdetailedtime and showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-        print(_output.format(time.asctime(), pos, level, txt))
-    elif not showdetailedtime and showinconsole:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-        print(_output.format(_output.time1(), pos, level, txt))
-    elif showdetailedtime and not showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-    else:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-    if debugin and not showdetailedtime:
-        return _output.format(_output.time1(), pos, level, txt)
-    elif debugin and showdetailedtime:
-        return _output.format(time.asctime(), pos, level, txt)
-    f.close()
+        log(txt, type='WARN', pos=pos)
 
 
 def error(txt, pos="main"):
     """
         :param txt: the detail description of this log
         :param pos: show where the log's actual called positon in the code
-        :return:
+        :return: error log
         """
-    level = 'ERROR'
-    if absolutepath:
-        f = open(route, mode="at+", encoding=file_encoding)
+    if debugin:
+        return log(txt, type='ERROR', pos=pos)
     else:
-        f = open(name + filetype, mode="at+", encoding=file_encoding)
-    if showdetailedtime and showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-        print(_output.format(time.asctime(), pos, level, txt))
-    elif not showdetailedtime and showinconsole:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-        print(_output.format(_output.time1(), pos, level, txt))
-    elif showdetailedtime and not showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-    else:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-    if debugin and not showdetailedtime:
-        return _output.format(_output.time1(), pos, level, txt)
-    elif debugin and showdetailedtime:
-        return _output.format(time.asctime(), pos, level, txt)
-    f.close()
+        log(txt, type='ERROR', pos=pos)
 
 
 def fatal(txt, pos="main"):
     """
     :param txt: the detail description of this log
     :param pos: show where the log's actual called positon in the code
-    :return:
+    :return: fatal log
     """
-    level = 'FATAL'
-    if absolutepath:
-        f = open(route, mode="at+", encoding=file_encoding)
+    if debugin:
+        return log(txt, type='FATAL', pos=pos)
     else:
-        f = open(name + filetype, mode="at+", encoding=file_encoding)
-    if showdetailedtime and showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-        print(_output.format(time.asctime(), pos, level, txt))
-    elif not showdetailedtime and showinconsole:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-        print(_output.format(_output.time1(), pos, level, txt))
-    elif showdetailedtime and not showinconsole:
-        f.write(_output.format(time.asctime(), pos, level, txt))
-    else:
-        f.write(_output.format(_output.time1(), pos, level, txt))
-    if debugin and not showdetailedtime:
-        return _output.format(_output.time1(), pos, level, txt)
-    elif debugin and showdetailedtime:
-        return _output.format(time.asctime(), pos, level, txt)
-    f.close()
+        log(txt, type='FATAL', pos=pos)
+    if fatalclose:
+        exit(10)
 
 
 def config(**kwargs):
@@ -178,9 +134,11 @@ def config(**kwargs):
 
     showinconsole : whether to show the log in the python console
 
+    fatalexit : whether to exit the program after a fatal log
+
     :return:
     """
-    global showinconsole, showdetailedtime, absolutepath, name, filetype, file_encoding, route,debugin
+    global showinconsole, showdetailedtime, absolutepath, name, filetype, file_encoding, route, debugin, fatalclose
     for configname, configdata in kwargs.items():
 
         if configname == "name":
@@ -203,21 +161,21 @@ def config(**kwargs):
                 if absolutepath:
                     tmpf = open(route, mode="w", encoding=configname)
                 else:
-                    tmpf = open(name+filetype, mode="w", encoding=configname)
+                    tmpf = open(name + filetype, mode="w", encoding=configname)
                 tmpf.close()
                 file_encoding = configname
                 del tmpf
                 if absolutepath:
                     f = open(route, mode="w", encoding=file_encoding)
                 else:
-                    f = open(name+filetype, mode="w", encoding=file_encoding)
+                    f = open(name + filetype, mode="w", encoding=file_encoding)
                 f.close()
             except LookupError:
                 warn("wrong file encoding config.this config is set to normal", pos="main_loggerjava")
                 file_encoding = "utf-8"
 
         elif configname == "showdetailedtime":
-            if configdata or not configdata:
+            if _formats.testformat(configdata, 1):
                 showdetailedtime = configdata
             else:
                 tmpin = showinconsole
@@ -228,19 +186,19 @@ def config(**kwargs):
                 del tmpin
 
         elif configname == "showinconsole":
-            if configdata or not configdata:
+            if _formats.testformat(configdata, 1):
                 showinconsole = configdata
             else:
                 showinconsole = True
                 warn("wrong show in console config.this config is set to normal", pos="main_loggerjava")
 
         elif configname == "absolutepath":
-            if configdata or not configdata:
+            if _formats.testformat(configdata, 1):
                 absolutepath = configdata
                 if absolutepath:
                     f = open(route, mode="w", encoding=file_encoding)
                 else:
-                    f = open(name+filetype, mode="w", encoding=file_encoding)
+                    f = open(name + filetype, mode="w", encoding=file_encoding)
                 f.close()
             else:
                 tmpin = showinconsole
@@ -253,6 +211,12 @@ def config(**kwargs):
                 del tmpin
         elif configname == "debuging":
             debugin = configdata
+        elif configname == "fatalexit":
+            if _formats.testformat(configdata, 1):
+                fatalclose = configdata
+            else:
+                warn("wrong fatal exit config.this config is set to normal", pos="main_loggerjava")
+                fatalclose = False
 
 
 def version():
@@ -263,6 +227,10 @@ def version():
     print("Current loggerjava ver:%s" % ver)
 
 
+def test():
+    loggerjava.test_loggerjava.testin()
+
+
 def exportconfig():
     """
     export current config
@@ -272,7 +240,7 @@ def exportconfig():
     """
     i = {"name": name, "filetype": filetype, "absolutepath": absolutepath,
          "route": route, "showdetailedtime": showdetailedtime, "showinconsole": showinconsole,
-         "file_encoding": file_encoding}
+         "file_encoding": file_encoding, "fatalexit": fatalclose}
     return i
 
 
@@ -281,9 +249,9 @@ def loadconfig(inputconfig):
     :param inputconfig: the config lib exported from exportconfig()
     :return:
     """
-    global name, showdetailedtime, showinconsole, absolutepath, filetype, file_encoding, route
+    global name, showdetailedtime, showinconsole, absolutepath, filetype, file_encoding, route, fatalclose
 
-    if inputconfig["absolutepath"] or not inputconfig["absolutepath"]:
+    if _formats.testformat(inputconfig["absolutepath"], 1):
         absolutepath = inputconfig["absolutepath"]
     else:
         tmpin = showinconsole
@@ -315,7 +283,7 @@ def loadconfig(inputconfig):
         f = open(name + filetype, mode="at+", encoding=file_encoding)
     f.close()
 
-    if inputconfig["showdetailedtime"] or not inputconfig["showdetailedtime"]:
+    if _formats.testformat(inputconfig["showdetailedtime"], 1):
         showdetailedtime = inputconfig["showdetailedtime"]
     else:
         tmpin = showinconsole
@@ -325,16 +293,56 @@ def loadconfig(inputconfig):
         showdetailedtime = False
         del tmpin
 
-    if inputconfig["showinconsole"] or not inputconfig["showinconsole"]:
+    if _formats.testformat(inputconfig["showinconsole"], 1):
         showinconsole = inputconfig["showinconsole"]
     else:
         showinconsole = True
         warn("wrong show in console config.this config is set to normal", pos="main_loggerjava")
 
+    if _formats.testformat(inputconfig["fatalexit"], 1):
+        fatalclose = inputconfig["fatalexit"]
+    else:
+        fatalclose = False
+        tmpin = showinconsole
+        showinconsole = True
+        warn("wrong fatal close config.this config is set to normal", pos="main_loggerjava")
+        showinconsole = tmpin
+        del tmpin
+
+
 # noinspection PyMethodParameters
 
 
-class _output:
+class _formats:
+    def typeformat(type):
+        debugformat = ["D", "d", "DEBUG", "debug"]
+        infoformat = ["I", "i", "INFO", "info"]
+        warnformat = ["W", "w", "WARN", "warn"]
+        errorformat = ["E", "e", "ERROR", "error"]
+        fatalformat = ["F", "f", "FATAL", "fatal"]
+
+        if type in debugformat:
+            return "debug"
+        elif type in infoformat:
+            return "INFO"
+        elif type in warnformat:
+            return "WARN"
+        elif type in errorformat:
+            return "ERROR"
+        elif type in fatalformat:
+            return "FATAL"
+        else:
+            warn("unknown given format", pos="main_loggerjava")
+            return "WARN"
+
+    def testformat(name, type):
+        if type == 1:
+            if name or not name:
+                return True
+            else:
+                return False
+        elif type == 2:
+            pass
 
     def format(time1, place, level, txt):
         return "[%s] [%s/%s]: %s\n" % (time1, place, level, txt)
